@@ -1,7 +1,7 @@
 package Net::OpenStack::Compute;
 use Any::Moose;
 
-our $VERSION = '1.0302'; # VERSION
+our $VERSION = '1.0400'; # VERSION
 
 use Carp;
 use HTTP::Request;
@@ -52,9 +52,16 @@ sub get_servers {
 sub get_server {
     my ($self, $id) = @_;
     my $res = $self->_ua->get($self->_url("/servers/$id"));
+    return undef unless $res->is_success;
     return from_json($res->content)->{server};
 }
 
+sub get_servers_by_name {
+    my ($self, $name) = @_;
+    my $servers = $self->get_servers(detail => 1);
+    return [ grep { $_->{name} eq $name } @$servers ];
+}
+
 sub create_server {
     my ($self, %params) = @_;
     my ($name, $flavor, $image) = @params{qw(name flavor image)};
@@ -81,8 +88,7 @@ sub delete_server {
     my ($self, $id) = @_;
     my $req = HTTP::Request->new(DELETE => $self->_url("/servers/$id"));
     my $res = $self->_ua->request($req);
-    _check_res($res);
-    return 1;
+    return $res->is_success;
 }
 
 sub get_images {
@@ -147,7 +153,7 @@ sub _url {
 
 sub _check_res { croak $_[0]->content unless $_[0]->is_success }
 
-# ABSTRACT: Bindings for the OpenStack compute api.
+# ABSTRACT: Bindings for the OpenStack Compute API.
 
 
 1;
@@ -157,11 +163,11 @@ __END__
 
 =head1 NAME
 
-Net::OpenStack::Compute - Bindings for the OpenStack compute api.
+Net::OpenStack::Compute - Bindings for the OpenStack Compute API.
 
 =head1 VERSION
 
-version 1.0302
+version 1.0400
 
 =head1 SYNOPSIS
 
@@ -177,9 +183,8 @@ version 1.0302
 
 =head1 DESCRIPTION
 
-This is the main class responsible for interacting with OpenStack Compute.
-Also see L<oscompute> for the command line tool that is a wrapper for this
-class.
+This class is an interface to the OpenStack Compute API.
+Also see the L<oscompute> command line tool.
 
 =head1 METHODS
 
@@ -187,10 +192,20 @@ class.
 
     get_server($id)
 
+Returns the server with the given id or undef if it doesn't exist.
+
 =head2 get_servers
 
     get_servers()
-    get_servers(detail => 0) # Detail defaults to 1.
+    get_servers(detail => 1) # Detail defaults to 0.
+
+Returns an arrayref of all the servers.
+
+=head2 get_servers_by_name
+
+    get_servers_by_name($name)
+
+Returns an arrayref of servers with the given name.
 
 =head2 create_server
 
@@ -207,7 +222,7 @@ class.
 =head2 get_images
 
     get_images()
-    get_images(detail => 0) # Detail defaults to 1.
+    get_images(detail => 1) # Detail defaults to 0.
 
 =head2 create_image
 
@@ -224,7 +239,28 @@ class.
 =head2 get_flavors
 
     get_flavors()
-    get_flavors(detail => 0) # Detail defaults to 1.
+    get_flavors(detail => 1) # Detail defaults to 0.
+
+=head2 token
+
+    token()
+
+Returns the OpenStack Compute API auth token.
+
+=head2 base_url
+
+    base_url()
+
+Returns the base url for the OpenStack Compute API, which is returned by the
+server after authenticating.
+
+=head1 SEE ALSO
+
+=over
+
+=item L<oscompute>
+
+=back
 
 =head1 AUTHOR
 
